Configure

Trait Configure 

pub trait Configure {
    // Required methods
    fn configure_endpoint(&self, endpoint: String);
    fn configure_labelers_header(&self, labeler_dids: Option<Vec<(Did, bool)>>);
    fn configure_proxy_header(&self, did: Did, service_type: impl AsRef<str>);
}
Available on crate feature agent only.
A trait for configuring the endpoint and headers of a client.

Required Methods

fn configure_endpoint(&self, endpoint: String)

Set the current endpoint.

fn configure_labelers_header(&self, labeler_dids: Option<Vec<(Did, bool)>>)

Configures the moderation services to be applied on requests.

fn configure_proxy_header(&self, did: Did, service_type: impl AsRef<str>)

Configures the atproto-proxy header to be applied on requests.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<M> Configure for Agent<M>

Source

impl<S, T, U> Configure for SessionClient<S, T, U>

Source

impl<S, T> Configure for CredentialSession<S, T>
where S: AtpSessionStore + Send + Sync, T: XrpcClient + Send + Sync, S::Error: Error + Send + Sync + 'static,