pub struct VerificationStateData {
pub trusted_verifier_status: String,
pub verifications: Vec<VerificationView>,
pub verified_status: String,
}Available on crate feature
namespace-appbsky only.Expand description
Represents the verification information about the user this object is attached to.
Fields
trusted_verifier_status: StringThe user’s status as a trusted verifier.
verifications: Vec<VerificationView>All verifications issued by trusted verifiers on behalf of this user. Verifications by untrusted verifiers are not included.
verified_status: StringThe user’s status as a verified account.