Module embed

Module embed 

Available on crate feature namespace-appbsky only.
Definitions for the app.bsky.embed namespace.

Modules

defs
Definitions for the app.bsky.embed.defs namespace.
external
Definitions for the app.bsky.embed.external namespace.
images
Definitions for the app.bsky.embed.images namespace. A set of images embedded in a Bluesky record (eg, a post).
record
Definitions for the app.bsky.embed.record namespace. A representation of a record embedded in a Bluesky record (eg, a post). For example, a quote-post, or sharing a feed generator record.
record_with_media
Definitions for the app.bsky.embed.recordWithMedia namespace. A representation of a record embedded in a Bluesky record (eg, a post), alongside other compatible embeds. For example, a quote post and image, or a quote post and external URL card.
video
Definitions for the app.bsky.embed.video namespace. A video embedded in a Bluesky record (eg, a post).