pub struct SelfLabelData {
pub val: String,
}Expand description
Metadata tag on an atproto record, published by the author within the record. Note that schemas should use #selfLabels, not #selfLabel.
Fields
val: StringThe short string name of the value or type of this label.