pub trait Configure {
// Required methods
fn configure_endpoint(&self, endpoint: String);
fn configure_labelers_header(&self, labeler_dids: Option<Vec<(Did, bool)>>);
fn configure_proxy_header(&self, did: Did, service_type: impl AsRef<str>);
}Available on crate feature
agent only.Expand description
A trait for configuring the endpoint and headers of a client.
Required Methods
Sourcefn configure_endpoint(&self, endpoint: String)
fn configure_endpoint(&self, endpoint: String)
Set the current endpoint.
Sourcefn configure_labelers_header(&self, labeler_dids: Option<Vec<(Did, bool)>>)
fn configure_labelers_header(&self, labeler_dids: Option<Vec<(Did, bool)>>)
Configures the moderation services to be applied on requests.
Sourcefn configure_proxy_header(&self, did: Did, service_type: impl AsRef<str>)
fn configure_proxy_header(&self, did: Did, service_type: impl AsRef<str>)
Configures the atproto-proxy header to be applied on requests.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".